searchData={"items":[{"type":"module","title":"MdnsLite","doc":"MdnsLite is a simple, limited, no frills mDNS implementation\n\nAdvertising hostnames and services is generally done using the application\nconfig.  See `MdnsLite.Options` for documentation.\n\nTo change the advertised hostnames or services at runtime, see `set_host/1`,\n`add_mdns_service/1` and `remove_mdns_service/1`.\n\nMdnsLite's mDNS record tables and caches can be inspected using\n`MdnsLite.Info` if you're having trouble.\n\nFinally, check out the MdnsLite `README.md` for more information.","ref":"MdnsLite.html"},{"type":"function","title":"MdnsLite.add_mdns_service/1","doc":"Start advertising a service\n\nServices can be added at compile-time via the `:services` key in the `mdns_lite`\napplication environment or they can be added at runtime using this function.\nSee the `service` type for information on what's needed.\n\nExample:\n\n```elixir\niex> service = %{\n    id: :my_web_server,\n    protocol: \"http\",\n    transport: \"tcp\",\n    port: 80\n  }\niex> MdnsLite.add_mdns_service(service)\n:ok\n```","ref":"MdnsLite.html#add_mdns_service/1"},{"type":"function","title":"MdnsLite.gethostbyname/2","doc":"Lookup a hostname using mDNS\n\nThe hostname should be a .local name since the query only goes out via mDNS.\nOn success, an IP address is returned.","ref":"MdnsLite.html#gethostbyname/2"},{"type":"function","title":"MdnsLite.remove_mdns_service/1","doc":"Stop advertising a service\n\nExample:\n\n```elixir\niex> MdnsLite.remove_mdns_service(:my_ssh)\n:ok\n```","ref":"MdnsLite.html#remove_mdns_service/1"},{"type":"function","title":"MdnsLite.set_hosts/1","doc":"Set the list of host names\n\nThis replaces the list of hostnames that MdnsLite will respond to. The first\nhostname in the list is special. Service advertisements will use it. The\nremainder are aliases.\n\nHostnames should not have the \".local\" extension. MdnsLite will add it.\n\nTo specify the hostname returned by `:inet.gethostname/0`, use `:hostname`.\n\nTo make MdnsLite respond to queries for \" .local\" and\n\"nerves.local\", run this:\n\n```elixir\niex> MdnsLite.set_hosts([:hostname, \"nerves\"])\n:ok\n```","ref":"MdnsLite.html#set_hosts/1"},{"type":"function","title":"MdnsLite.set_instance_name/1","doc":"Updates the advertised instance name for service records\n\nTo specify the first hostname specified in `hosts`, use `:unspecified`","ref":"MdnsLite.html#set_instance_name/1"},{"type":"type","title":"MdnsLite.instance_name/0","doc":"A user-visible name for a service advertisement","ref":"MdnsLite.html#t:instance_name/0"},{"type":"type","title":"MdnsLite.service/0","doc":"mDNS service description\n\nKeys include:\n\n* `:id` - an atom for referring to this service (only required if you want to\n  reference the service at runtime)\n* `:port` - the TCP/UDP port number for the service (required)\n* `:transport` - the transport protocol. E.g., `\"tcp\"` (specify this and\n  `:protocol`, or `:type`) * `:protocol` - the application protocol. E.g.,\n  `\"ssh\"` (specify this and `:transport`, or `:type`)\n* `:type` - the transport/protocol to advertize. E.g., `\"_ssh._tcp\"` (only\n  needed if `:protocol` and `:transport` aren't specified)\n* `:weight` - the service weight. Defaults to `0`. (optional)\n* `:priority` - the service priority. Defaults to `0`. (optional)\n* `:txt_payload` - a list of strings to advertise\n\nExample:\n\n```\n%{id: :my_ssh, port: 22, protocol: \"ssh\", transport: \"tcp\"}\n```","ref":"MdnsLite.html#t:service/0"},{"type":"type","title":"MdnsLite.service_id/0","doc":"A user-specified ID for referring to a service\n\nAtoms are recommended, but binaries are still supported since they were used\nin the past.","ref":"MdnsLite.html#t:service_id/0"},{"type":"module","title":"MdnsLite.Cache","doc":"Cache for records received over mDNS","ref":"MdnsLite.Cache.html"},{"type":"function","title":"MdnsLite.Cache.gc/2","doc":"Remove any expired entries","ref":"MdnsLite.Cache.html#gc/2"},{"type":"function","title":"MdnsLite.Cache.insert/3","doc":"Insert a record into the cache","ref":"MdnsLite.Cache.html#insert/3"},{"type":"function","title":"MdnsLite.Cache.insert_many/3","doc":"Insert several record into the cache","ref":"MdnsLite.Cache.html#insert_many/3"},{"type":"function","title":"MdnsLite.Cache.new/0","doc":"Start an empty cache","ref":"MdnsLite.Cache.html#new/0"},{"type":"function","title":"MdnsLite.Cache.query/2","doc":"Run a query against the cache\n\nIMPORTANT: The cache is not garbage collected, so it can return stale entries.\nCall `gc/2` first to expire old entries.","ref":"MdnsLite.Cache.html#query/2"},{"type":"type","title":"MdnsLite.Cache.t/0","doc":"","ref":"MdnsLite.Cache.html#t:t/0"},{"type":"type","title":"MdnsLite.Cache.timestamp/0","doc":"Timestamp in seconds (assumed monotonic)","ref":"MdnsLite.Cache.html#t:timestamp/0"},{"type":"module","title":"MdnsLite.CoreMonitor","doc":"Core logic for network monitors\n\nThis module contains most of the logic needed for writing a network monitor.\nIt's only intended to be called from `MdnsLite.InetMonitor` and\n`MdnsLite.VintageNetMonitor`.","ref":"MdnsLite.CoreMonitor.html"},{"type":"function","title":"MdnsLite.CoreMonitor.flush_todo_list/1","doc":"","ref":"MdnsLite.CoreMonitor.html#flush_todo_list/1"},{"type":"function","title":"MdnsLite.CoreMonitor.init/1","doc":"","ref":"MdnsLite.CoreMonitor.html#init/1"},{"type":"function","title":"MdnsLite.CoreMonitor.set_ip_list/3","doc":"","ref":"MdnsLite.CoreMonitor.html#set_ip_list/3"},{"type":"function","title":"MdnsLite.CoreMonitor.unset_remaining_ifnames/2","doc":"","ref":"MdnsLite.CoreMonitor.html#unset_remaining_ifnames/2"},{"type":"type","title":"MdnsLite.CoreMonitor.option/0","doc":"Monitor options\n\n* `:excluded_ifnames` - a list of network interface names to ignore\n* `:ipv4_only` - set to `true` to ignore all IPv6 addresses","ref":"MdnsLite.CoreMonitor.html#t:option/0"},{"type":"module","title":"MdnsLite.DNS","doc":"Bring Erlang's DNS record definitions into Elixir","ref":"MdnsLite.DNS.html"},{"type":"function","title":"MdnsLite.DNS.decode/1","doc":"Decode a packet that contains a DNS message","ref":"MdnsLite.DNS.html#decode/1"},{"type":"macro","title":"MdnsLite.DNS.dns_header/1","doc":"","ref":"MdnsLite.DNS.html#dns_header/1"},{"type":"macro","title":"MdnsLite.DNS.dns_header/2","doc":"","ref":"MdnsLite.DNS.html#dns_header/2"},{"type":"macro","title":"MdnsLite.DNS.dns_query/1","doc":"","ref":"MdnsLite.DNS.html#dns_query/1"},{"type":"macro","title":"MdnsLite.DNS.dns_query/2","doc":"","ref":"MdnsLite.DNS.html#dns_query/2"},{"type":"macro","title":"MdnsLite.DNS.dns_rec/1","doc":"","ref":"MdnsLite.DNS.html#dns_rec/1"},{"type":"macro","title":"MdnsLite.DNS.dns_rec/2","doc":"","ref":"MdnsLite.DNS.html#dns_rec/2"},{"type":"macro","title":"MdnsLite.DNS.dns_rr/1","doc":"","ref":"MdnsLite.DNS.html#dns_rr/1"},{"type":"macro","title":"MdnsLite.DNS.dns_rr/2","doc":"","ref":"MdnsLite.DNS.html#dns_rr/2"},{"type":"function","title":"MdnsLite.DNS.encode/1","doc":"Encode a DNS record","ref":"MdnsLite.DNS.html#encode/1"},{"type":"function","title":"MdnsLite.DNS.pretty/1","doc":"Format a DNS record as a nice string for the user","ref":"MdnsLite.DNS.html#pretty/1"},{"type":"type","title":"MdnsLite.DNS.dns_query/0","doc":"","ref":"MdnsLite.DNS.html#t:dns_query/0"},{"type":"type","title":"MdnsLite.DNS.dns_rec/0","doc":"","ref":"MdnsLite.DNS.html#t:dns_rec/0"},{"type":"type","title":"MdnsLite.DNS.dns_rr/0","doc":"","ref":"MdnsLite.DNS.html#t:dns_rr/0"},{"type":"module","title":"MdnsLite.DNSBridge","doc":"DNS server that responds to mDNS queries\n\nThis is a simple DNS server that can be used to resolve mDNS queries\nso that the rest of Erlang and Elixir can seamlessly use mDNS. To use\nthis, you must enable the `:dns_bridge_enabled` option and then make the\nfirst DNS server be this server's IP address and port.\n\nThis DNS server can either return an error or recursively look up a non-mDNS record\ndepending on how it's configured. Erlang's DNS resolver currently has an issue\nwith the error strategy so it can't be used.\n\nConfigure this using the following application environment options:\n\n* `:dns_bridge_enabled` - set to true to enable the bridge\n* `:dns_bridge_ip` - IP address in tuple form for server (defaults to `{127, 0, 0, 53}`)\n* `:dns_bridge_port` - UDP port for server (defaults to 53)\n* `:dns_bridge_recursive` - set to true to recursively look up non-mDNS queries","ref":"MdnsLite.DNSBridge.html"},{"type":"function","title":"MdnsLite.DNSBridge.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"MdnsLite.DNSBridge.html#child_spec/1"},{"type":"module","title":"MdnsLite.InetMonitor","doc":"Network monitor that uses Erlang's :inet functions\n\nUse this network monitor to detect new network interfaces and their\nIP addresses when not using Nerves. It regularly polls the system\nfor changes so it's not as fast at starting mDNS responders as\nthe `MdnsLite.VintageNetMonitor` is. However, it works everywhere.\n\nSee `MdnsLite.Options` for how to set your `config.exs` to use it.","ref":"MdnsLite.InetMonitor.html"},{"type":"function","title":"MdnsLite.InetMonitor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"MdnsLite.InetMonitor.html#child_spec/1"},{"type":"module","title":"MdnsLite.Info","doc":"Inspect internal MdnsLite state\n\nFunctions in this module are intended for debugging mDNS issues.","ref":"MdnsLite.Info.html"},{"type":"function","title":"MdnsLite.Info.dump_caches/0","doc":"Dump the contents of the responder mDNS caches","ref":"MdnsLite.Info.html#dump_caches/0"},{"type":"function","title":"MdnsLite.Info.dump_records/0","doc":"Dump the records that mDNSLite advertises","ref":"MdnsLite.Info.html#dump_records/0"},{"type":"module","title":"MdnsLite.Options","doc":"MdnsLite options\n\nMdnsLite is usually configured in a project's application environment\n(`config.exs`) as follows:\n\n```elixir\nconfig :mdns_lite,\n  hosts: [:hostname, \"nerves\"],\n  ttl: 120,\n\n  instance_name: \"mDNS Lite Device\",\n\n  services: [\n    %{\n      id: :web_server,\n      protocol: \"http\",\n      transport: \"tcp\",\n      port: 80,\n      txt_payload: [\"key=value\"]\n    },\n    %{\n      id: :ssh_daemon,\n      instance_name: \"More particular mDNS Lite Device\"\n      protocol: \"ssh\",\n      transport: \"tcp\",\n      port: 22\n    }\n  ]\n```\n\nThe configurable keys are:\n\n* `:hosts` - A list of hostnames to respond to. Normally this would be set to\n  `:hostname` and `mdns_lite` will advertise the actual hostname with `.local`\n  appended.\n* `:ttl` - The default mDNS record time-to-live. The default of 120\n  seconds is probably fine for most use. See [RFC 6762 - Multicast\n  DNS](https://tools.ietf.org/html/rfc6762) for considerations.\n* `instance_name` - A user friendly name that will be used as the name for this\n  device's advertised service(s). Per RFC6763 Appendix C, this should describe\n   the user-facing purpose or description of the device, and should not be\n   considered a unique identifier. For example, 'Nerves Device' and 'MatCo\n   Laser Printer Model CRM-114' are good choices here.  If instance_name is not\n   defined it defaults to the first entry in the `hosts` list\n* `:excluded_ifnames` - A list of network interfaces names to ignore. By\n  default, `mdns_lite` will ignore loopback and cellular network interfaces.\n* `:ipv4_only` - Set to `true` to only respond on IPv4 interfaces. Since IPv6\n  isn't fully supported yet, this is the default. Note that it's still\n  possible to get AAAA records when using IPv4.\n* `:if_monitor` - Set to `MdnsLite.VintageNetMonitor` when using Nerves or\n  `MdnsLite.InetMonitor` elsewhere.  The default is\n  `MdnsLite.VintageNetMonitor`.\n* `:dns_bridge_enabled` - Set to `true` to start a DNS server running that\n  will bridge DNS to mDNS.\n* `:dns_bridge_ip` - The IP address for the DNS server. Defaults to\n  127.0.0.53.\n* `:dns_bridge_port` - The UDP port for the DNS server. Defaults to 53.\n* `:dns_bridge_recursive` - If a regular DNS request comes on the DNS bridge,\n  forward it to a DNS server rather than returning an error. This is the\n  default since there's an issue on Linux and Nerves that prevents Erlang's\n  DNS resolver from checking the next one.\n* `:services` - A list of services to advertise. See `MdnsLite.service` for\n  details.\n\nSome options are modifiable at runtime. Functions for modifying these are in\nthe `MdnsLite` module.","ref":"MdnsLite.Options.html"},{"type":"function","title":"MdnsLite.Options.normalize_service/1","doc":"Normalize a service description\n\nAll service descriptions are normalized before use. Call this function if\nyou're unsure how the service description will be transformed for use.","ref":"MdnsLite.Options.html#normalize_service/1"},{"type":"module","title":"MdnsLite.VintageNetMonitor","doc":"Network monitor that using VintageNet\n\nUse this network monitor to detect new network interfaces and their\nIP addresses when using Nerves. It is the default.","ref":"MdnsLite.VintageNetMonitor.html"},{"type":"function","title":"MdnsLite.VintageNetMonitor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"MdnsLite.VintageNetMonitor.html#child_spec/1"},{"type":"function","title":"MdnsLite.VintageNetMonitor.start_link/1","doc":"","ref":"MdnsLite.VintageNetMonitor.html#start_link/1"},{"type":"extras","title":"MdnsLite","doc":"# MdnsLite\n\n[![Hex version](https://img.shields.io/hexpm/v/mdns_lite.svg \"Hex version\")](https://hex.pm/packages/mdns_lite)\n[![CircleCI](https://circleci.com/gh/nerves-networking/mdns_lite.svg?style=svg)](https://circleci.com/gh/nerves-networking/mdns_lite)\n\nMdnsLite is a simple, limited, no frills implementation of an\n[mDNS](https://en.wikipedia.org/wiki/Multicast_DNS) (Multicast Domain Name\nSystem) client and server. It operates like DNS, but uses multicast instead of\nunicast so that any computer on a LAN can help resolve names. In particular, it\nresolves hostnames that end in `.local` and provides a way to advertise and\ndiscovery service.\n\nMdnsLite is intended for environments like on Nerves devices that do not already\nhave an `mDNS` service. If you're running on desktop Linux or on MacOS, you\nalready have `mDNS` support and do not need MdnsLite.\n\nFeatures of MdnsLite:\n\n* Advertise ` .local` and aliases for ease of finding devices\n* Static (application config) and dynamic service registration\n* Support for multi-homed devices. For example, mDNS responses sent on a network\n  interface have the expected IP addresses for that interface.\n* DNS bridging so that Erlang's built-in DNS resolver can look up `.local` names\n  via mDNS.\n* Caching of results and advertisements seen on the network\n* Integration with\n  [VintageNet](https://github.com/nerves-networking/vintage_net) and Erlang's\n  `:inet` application for network interface monitoring\n* Easy inspection of mDNS record tables to help debug service discovery issues\n\nMdnsLite is included in [NervesPack](https://hex.pm/packages/nerves_pack) so you\nmight already have it!","ref":"readme.html"},{"type":"extras","title":"Configuration - MdnsLite","doc":"A typical configuration in the `config.exs` file looks like:\n\n```elixir\nconfig :mdns_lite,\n  # Advertise `hostname.local` on the LAN\n  hosts: [:hostname],\n  # If instance_name is not defined it defaults to the first hostname\n  instance_name: \"Awesome Device\",\n  services: [\n    # Advertise an HTTP server running on port 80\n    %{\n      id: :web_service,\n      protocol: \"http\",\n      transport: \"tcp\",\n      port: 80,\n    },\n    # Advertise an SSH daemon on port 22\n    %{\n      id: :ssh_daemon,\n      protocol: \"ssh\",\n      transport: \"tcp\",\n      port: 22,\n    }\n  ]\n```\n\nThe `services` section lists the services that the host offers, such as\nproviding an HTTP server. Specifying a `protocol`, `transport` and `port` is\nusually the easiest way. The `protocol` and `transport` get combined to form the\nservice type that's actually advertised on the network. For example, a \"tcp\"\ntransport and \"ssh\" protocol will end up as `\"_ssh._tcp\"` in the advertisement.\nIf you need something custom, specify `:type` directly. Optional fields include\n`:id`, `:weight`, `:priority`, `:instance_name` and `:txt_payload`. An `:id` is\nneeded to remove the service advertisement at runtime. If not specified,\n`:instance_name` is inherited from the top-level config.  A `:txt_payload` is a\nlist of `\" = \"` string that will be advertised in a TXT DNS record\ncorresponding to the service.\n\nSee [`MdnsLite.Options`](https://hexdocs.pm/mdns_lite/MdnsLite.Options.html) for\ninformation about all application environment options.\n\nIt's possible to change the advertised hostnames, instance names and services at\nruntime. For example, to change the list of advertised hostnames, run:\n\n```elixir\niex> MdnsLite.set_hosts([:hostname, \"nerves\"])\n:ok\n```\n\nTo change the advertised instance name:\n\n```elixir\niex> MdnsLite.set_instance_name(\"My Other Awesome Device\")\n:ok\n```\n\nHere's how to add and remove a service at runtime:\n\n```elixir\niex> MdnsLite.add_mdns_service(%{\n    id: :my_web_server,\n    protocol: \"http\",\n    transport: \"tcp\",\n    port: 80,\n  })\n:ok\niex> MdnsLite.remove_mdns_service(:my_web_server)\n:ok\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Client - MdnsLite","doc":"`MdnsLite.gethostbyname/1` uses mDNS to resolve hostnames. Here's an example:\n\n```elixir\niex> MdnsLite.gethostbyname(\"my-laptop.local\")\n{:ok, {172, 31, 112, 98}}\n```\n\nIf you just want mDNS to \"just work\" with Erlang, you'll need to enable\nMdnsLite's DNS Bridge feature and configure Erlang's DNS resolver to use it. See\nthe DNS Bridge section for details.\n\nService discovery docs TBD...","ref":"readme.html#client"},{"type":"extras","title":"DNS Bridge configuration - MdnsLite","doc":"`MdnsLite` can start a DNS server to respond to `.local` queries. This enables\ncode that has no knowledge of mDNS to resolve mDNS queries. For example,\nErlang/OTP's built-in DNS resolver doesn't know about mDNS. It's used to resolve\nhosts for Erlang distribution and pretty much any code using `:gen_tcp` and\n`:gen_udp`. `MdnsLite`'s DNS bridge feature makes `.local` hostname lookups work\nfor all of this. No code modifications required.\n\nNote that this feature is useful on Nerves devices. Erlang/OTP can use the\nsystem name resolver on desktop Linux and MacOS. The system name resolver should\nalready be hooked up to an mDNS resolver there.\n\nTo set this up, you'll need to enable the DNS bridge on `MdnsLite` and then set\nup the DNS resolver to use it first. Here are the options for the application\nenvironment:\n\n```elixir\nconfig :mdns_lite,\n  dns_bridge_enabled: true,\n  dns_bridge_ip: {127, 0, 0, 53},\n  dns_bridge_port: 53\n\nconfig :vintage_net,\n  additional_name_servers: [{127, 0, 0, 53}]\n```\n\nThe choice of running the DNS bridge on 127.0.0.53:53 is mostly arbitrary. This\nis the default.\n\n> #### Info {: .info}\n>\n> If you're using a version of Erlang/OTP before 24.1, you'll be affected by\n> [OTP #5092](https://github.com/erlang/otp/issues/5092). The workaround is to\n> add the `dns_bridge_recursive: true` option to the `:mdns_lite` config.","ref":"readme.html#dns-bridge-configuration"},{"type":"extras","title":"Debugging - MdnsLite","doc":"`MdnsLite` maintains a table of records that it advertises and a cache per\nnetwork interface. The table of records that it advertises is based solely off\nits configuration. Review it by running:\n\n```elixir\niex> MdnsLite.Info.dump_records\n .in-addr.arpa: type PTR, class IN, ttl 120, nerves-2e6d.local\n .ip6.arpa: type PTR, class IN, ttl 120, nerves-2e6d.local\n_epmd._tcp.local: type PTR, class IN, ttl 120, nerves-2e6d._epmd._tcp.local\n_services._dns-sd._udp.local: type PTR, class IN, ttl 120, _epmd._tcp.local\n_services._dns-sd._udp.local: type PTR, class IN, ttl 120, _sftp-ssh._tcp.local\n_services._dns-sd._udp.local: type PTR, class IN, ttl 120, _ssh._tcp.local\n_sftp-ssh._tcp.local: type PTR, class IN, ttl 120, nerves-2e6d._sftp-ssh._tcp.local\n_ssh._tcp.local: type PTR, class IN, ttl 120, nerves-2e6d._ssh._tcp.local\nnerves-2e6d._epmd._tcp.local: type SRV, class IN, ttl 120, priority 0, weight 0, port 4369, nerves-2e6d.local.\nnerves-2e6d._epmd._tcp.local: type TXT, class IN, ttl 120,\nnerves-2e6d._sftp-ssh._tcp.local: type SRV, class IN, ttl 120, priority 0, weight 0, port 22, nerves-2e6d.local.\nnerves-2e6d._sftp-ssh._tcp.local: type TXT, class IN, ttl 120,\nnerves-2e6d._ssh._tcp.local: type SRV, class IN, ttl 120, priority 0, weight 0, port 22, nerves-2e6d.local.\nnerves-2e6d._ssh._tcp.local: type TXT, class IN, ttl 120,\nnerves-2e6d.local: type A, class IN, ttl 120, addr  \nnerves-2e6d.local: type AAAA, class IN, ttl 120, addr  \n```\n\nNote that some addresses have not been filled in. They depend on which network\ninterface receives the query. The idea is that if a computer is looking for you\non the Ethernet interface, you should give records with that Ethernet's\ninterface rather than, say, the IP address of the WiFi interface.\n\n`MdnsLite`'s cache is filled with records that it sees advertised. It's\nbasically the same, but can be quite large depending on the mDNS activity on a\nlink. It looks like this:\n\n```elixir\niex> MdnsLite.Info.dump_caches\nResponder: 172.31.112.97\n  ...\nResponder: 192.168.1.58\n  ...\n```","ref":"readme.html#debugging"},{"type":"extras","title":"In memory - MdnsLite","doc":"[Peter Marks](https://github.com/pcmarks/) wrote and maintained the original\nversion of `mdns_lite`.","ref":"readme.html#in-memory"},{"type":"extras","title":"License - MdnsLite","doc":"Copyright (C) 2019-21 SmartRent\n\n    Licensed under the Apache License, Version 2.0 (the \"License\");\n    you may not use this file except in compliance with the License.\n    You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\n    Unless required by applicable law or agreed to in writing, software\n    distributed under the License is distributed on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n    See the License for the specific language governing permissions and\n    limitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nThis project follows [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"v0.8.11 - 2024-09-10 - Changelog","doc":"* Bug fixes\n  * Fix `MdnsLite.InetMonitor` to properly remove interfaces that don't exist in a subsequent update. (@kevinschweikert)\n  * Exclude \"__unknown\" interfaces to ignore interfaces that VintageNet can't get link info on. (@ConnorRigby)\n  * Don't crash on other Unix-like OSes (@mneumann)","ref":"changelog.html#v0-8-11-2024-09-10"},{"type":"extras","title":"v0.8.10 - 2024-02-26 - Changelog","doc":"* Bug fixes\n  * Really fix crash when cleaning up responders when a network goes down. The\n    fix in v0.8.9 had an issue that prevented it from working.","ref":"changelog.html#v0-8-10-2024-02-26"},{"type":"extras","title":"v0.8.9 - 2024-02-02 - Changelog","doc":"* Bug fixes\n  * Switch bridge recursive lookup to default to false. The issue that this\n    works around has been fixed since OTP 24.1.\n  * Handle crash when cleaning up responders when a network goes down.","ref":"changelog.html#v0-8-9-2024-02-02"},{"type":"extras","title":"v0.8.8 - 2023-05-26 - Changelog","doc":"* New feature\n  * IPv6 queries are now supported. Responding to IPv6 isn't supported yet. To\n    use this, be sure to set `ipv4_only: false` since this isn't the default.\n    Thanks to @bjyoungblood for this feature.","ref":"changelog.html#v0-8-8-2023-05-26"},{"type":"extras","title":"v0.8.7 - 2023-02-12 - Changelog","doc":"* Fixed\n  * Fix Elixir 1.15 deprecation warnings","ref":"changelog.html#v0-8-7-2023-02-12"},{"type":"extras","title":"v0.8.6 - 2022-06-14 - Changelog","doc":"* Fixed\n  * Fixed an issue that caused the DNS bridge to stop working with OTP 25.","ref":"changelog.html#v0-8-6-2022-06-14"},{"type":"extras","title":"v0.8.5 - 2022-04-28 - Changelog","doc":"* Fixed\n  * If a network interface changes IP addresses, there would be a flurry of\n    crashes when it was no longer possible to bind to the interface. This stops\n    behavior and shuts down the responder for the interface.","ref":"changelog.html#v0-8-5-2022-04-28"},{"type":"extras","title":"v0.8.4 - 2021-11-13 - Changelog","doc":"* New feature\n  * VintageNet is an optional dependency now. This makes it possible to use\n    MdnsLite outside of Nerves much more easily.\n\n* Fixed\n  * Use the new DNS encoder/decoder from OTP 24.1.5. This fixes a regression\n    with OTP 24.1.2 where the DNS encoder and decoder was updated to be more\n    correct in how it handled the DNS class. mDNS repurposes the high bit of the\n    DNS class. Previously we had gotten lucky. OTP 24.1.5 adds support for the\n    bit. To make sure that MdnsLite can work on other OTP versions, the new\n    OTP code has been vendored and included with MdnsLite.","ref":"changelog.html#v0-8-4-2021-11-13"},{"type":"extras","title":"v0.8.3 - 2021-10-07 - Changelog","doc":"* Fixed\n  * Added configuration and runtime support for setting the instance name. This\n    was incorrectly removed in v0.8.0. By default, MdnsLite will advertise\n    itself using the hostname. This works, but looks unfriendly in the service\n    discovery results. Setting the instance name lets you advertise with a nice\n    human readable name. Thanks to Mat Trudel for both catching this regression\n    and fixing it.","ref":"changelog.html#v0-8-3-2021-10-07"},{"type":"extras","title":"v0.8.2 - 2021-09-23 - Changelog","doc":"* Fixed\n  * Fix calls to `:socket.setopt/3` to support OTP 22 and OTP 23. Thanks to\n    Peter Madsen for finding this and providing a fix.","ref":"changelog.html#v0-8-2-2021-09-23"},{"type":"extras","title":"v0.8.1 - 2021-09-19 - Changelog","doc":"* Fixed\n  * Fix interface monitor crash when a network interface gets removed.","ref":"changelog.html#v0-8-1-2021-09-19"},{"type":"extras","title":"v0.8.0 - Changelog","doc":"This release is a major update to MdnsLite to support making queries in\naddition to responding to queries. The runtime API is not backwards compatible.\nIf you're only using the application environment to configure MdnsLite, you\nshould be ok.\n\n* New features\n  * Make mDNS requests\n  * Add a DNS bridge for Erlang's DNS resolver. This enables Erlang\n    distribution and `:gen_tcp` users to be passed `.local` hostnames. See docs\n    for how to configure\n  * mDNS record caching\n  * mDNS record inspection - both for ones MdnsLite advertises and for ones in\n    the caches\n  * AAAA record support - Proper IPv6 support is still not available\n\n* Bug fixes\n  * MdnsLite now uses `:socket` to send and receive mDNS messages. This fixes\n    several issues where multicast packets were being mixed up between network\n    interfaces.","ref":"changelog.html#v0-8-0"},{"type":"extras","title":"v0.7.0 - Changelog","doc":"* Breaking change\n  * Change optional dependency on VintageNet to a mandatory one. Probably all\n    `:mdns_lite` users were already using VintageNet and since Mix releases\n    doesn't support optional dependencies yet, some users got errors when the\n    release misordered them. This avoids the problem.\n\n* Improvements\n  * Removed the `:dns` package dependency. There as an Erlang crypto API call in\n    a dependency of `:dns` that was removed in OTP 24. This change makes it\n    possible to use `:mdns_lite` on OTP 24 without worrying about a missing\n    crypto API call.","ref":"changelog.html#v0-7-0"},{"type":"extras","title":"v0.6.7 - Changelog","doc":"* Improvements\n  * Exclude `\"wwan0\"` by default. These interfaces are cellular links like ppp\n    and it's not appropriate to respond to mDNS on them either.","ref":"changelog.html#v0-6-7"},{"type":"extras","title":"v0.6.6 - Changelog","doc":"* Bug fixes\n  * Advertise services based on service names & not hostname. Thanks to Matt\n    Trudel for this fix.","ref":"changelog.html#v0-6-6"},{"type":"extras","title":"v0.6.5 - Changelog","doc":"* Bug fixes\n  * Reuse addresses and ports when binding to the multicast socket to coexist\n    with other mDNS software. Thanks to Eduardo Cunha and Matt Myers for the\n    updates.","ref":"changelog.html#v0-6-5"},{"type":"extras","title":"v0.6.4 - Changelog","doc":"* New features\n  * Support custom TXT record contents. See the `:txt_payload`. Thanks to\n    Eduardo Cunha for adding this.","ref":"changelog.html#v0-6-4"},{"type":"extras","title":"v0.6.3 - Changelog","doc":"* Bug fixes\n  * Update default so that ppp interfaces are ignored. This prevents surprises\n    of having a responder run on a cellular link.","ref":"changelog.html#v0-6-3"},{"type":"extras","title":"v0.6.2 - Changelog","doc":"* Bug fixes\n  * Fix crash when handling undecodable mDNS messages","ref":"changelog.html#v0-6-2"},{"type":"extras","title":"v0.6.1 - Changelog","doc":"* Handle nil from VintageNet reports","ref":"changelog.html#v0-6-1"},{"type":"extras","title":"v0.6.0 - Changelog","doc":"* Allow mdns host to be change at runtime\n* New network monitor: VintageNetMonitor","ref":"changelog.html#v0-6-0"},{"type":"extras","title":"v0.5.0 - Changelog","doc":"* Allow services to be added and removed at runtime.","ref":"changelog.html#v0-5-0"},{"type":"extras","title":"v0.4.3 - Changelog","doc":"* Correct typos and white space\n* Comment out logger messages","ref":"changelog.html#v0-4-3"},{"type":"extras","title":"v0.4.2 - Changelog","doc":"* Remove un-helpful Logger.debug statements - Issue #49\n* Put this file into the proper order.","ref":"changelog.html#v0-4-2"},{"type":"extras","title":"v0.4.1 - Changelog","doc":"* Correct bad tag in README.md and correct grammar.\n* Correct documentation of the MdnsLite module","ref":"changelog.html#v0-4-1"},{"type":"extras","title":"v0.4.0 - Changelog","doc":"* The value of host in the configuration file can have two values. The second can serve as an alias for the first.\n* Updated documentation and comments.\n* Created a new test.","ref":"changelog.html#v0-4-0"},{"type":"extras","title":"v0.3.0 - Changelog","doc":"* Remove a superfluous map from the config.","ref":"changelog.html#v0-3-0"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"* Update README to reflect changes in previous version.","ref":"changelog.html#v0-2-1"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"* Much better alignment with RFC 6763 - DNS Service-based discovery.\n* Affects handling of SRV and PTR queries.","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"* Initial release","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}